@@ -132,6 +132,10 @@ my $type_map = {
 		"gtype" => "G_TYPE_OBJECT",
 		"assert" => "G_IS_OBJECT(__arg__)",
 		"fail_return" => "NULL"
+	},
+	"GFile*" => {
+		"gtype" => "G_TYPE_OBJECT",
+		"fail_return" => "NULL"
 	}
 };
 
@@ -208,6 +212,7 @@ while ($line = <INFILE>)
 	}
 	
 	my $class;
+	my $typedef_hr = {};
 	if (is_interface($line, \$class))
 	{
 		push @level, "interface";
@@ -237,15 +242,14 @@ while ($line = <INFILE>)
 		$linenum++;
 		next;
 	}
-	elsif (is_typedef($line, \$typedef))
+	elsif (is_typedef($line, $typedef_hr))
 	{
 		die "Parse error at $idl_file:$linenum: typedefs should only be in interface"
 			if (current_level(@level) ne "interface");
 		die "Parse error at $idl_file:$linenum: Class name expected"
 			if ($current_class eq "");
 		my $comments_in = get_comments();
-		compile_typedef($data_hr, $current_class, $comments_in, $typedef);
-		$typedef = "";
+		compile_typedef($data_hr, $current_class, $comments_in, $typedef_hr);
 		$linenum++;
 		next;
 	}
@@ -261,6 +265,18 @@ while ($line = <INFILE>)
 		$linenum++;
 		next;
 	}
+	my $define_hr = {};
+	if (is_define($line, $define_hr))
+	{
+		die "Parse error at $idl_file:$linenum: Defines should only be in interface"
+			if (current_level(@level) ne "interface");
+		die "Parse error at $idl_file:$linenum: Class name expected"
+			if ($current_class eq "");
+		my $comments_in = get_comments();
+		compile_define($data_hr, $current_class, $comments_in, $define_hr);
+		$linenum++;
+		next;
+	}
 	if (is_block_end($line))
 	{
 		if (current_level(@level) eq "interface")
@@ -401,7 +417,7 @@ sub is_struct
 
 sub is_typedef
 {
-	my ($line, $typedef_ref) = @_;
+	my ($line, $typedef_hr) = @_;
 	if ($line =~ /^\s*typedef\s*/)
 	{
 		## Check if it is variable typedef and grab the typedef name.
@@ -414,7 +430,7 @@ sub is_typedef
 		{
 			add_class_private ($current_class, $1);
 		}
-		$$typedef_ref = $line;
+		$typedef_hr->{'line'} = $line;
 		## print "Typedef: $line\n";
 		return 1;
 	}
@@ -449,6 +465,19 @@ sub is_method
 	return 0;
 }
 
+sub is_define
+{
+	my ($line, $define_hr) = @_;
+	if ($line =~ /^\s*#define\s+([\w_][\w\d_]*)\s+(.*)\s*$/)
+	{
+		$define_hr->{'name'} = $1;
+		$define_hr->{'value'} = $2;
+		## print "Define: $line\n";
+		return 1;
+	}
+	return 0;
+}
+
 sub normalize_namespace
 {
 	my ($current_class, $text) = @_;
@@ -575,16 +604,32 @@ sub compile_inclues
 	}	
 }
 
+sub compile_define
+{
+	my ($data_hr, $current_class, $comments, $define_hr) = @_;
+	my $class_hr = $data_hr->{$current_class};
+	if (!defined($class_hr->{"__defines"}))
+	{
+		$class_hr->{"__defines"} = [];
+	}
+	my $defines_lr = $class_hr->{'__defines'};
+		
+	$define_hr->{'__comments'} = $comments;
+	push (@$defines_lr, $define_hr);
+}
+
 sub compile_typedef
 {
-	my ($data_hr, $current_class, $comments, $typedef) = @_;
+	my ($data_hr, $current_class, $comments, $typedef_hr) = @_;
 	my $class_hr = $data_hr->{$current_class};
 	if (!defined($class_hr->{"__typedefs"}))
 	{
 		$class_hr->{"__typedefs"} = [];
 	}
 	my $typedefs_lr = $class_hr->{"__typedefs"};
-	push (@$typedefs_lr, $typedef);
+
+	$typedef_hr->{'__comments'} = $comments;
+	push (@$typedefs_lr, $typedef_hr);
 }
 
 sub compile_enum
@@ -714,13 +759,14 @@ sub get_canonical_names
 sub get_arg_type_info
 {
 	my ($type, $info) = @_;
-	if (defined ($type_map->{$type}))
+	if (defined ($type) && defined ($type_map->{$type}))
 	{
 		if (defined ($type_map->{$type}->{$info}))
 		{
 			return $type_map->{$type}->{$info};
 		}
 	}
+	return "";
 }
 
 sub get_return_type_val
@@ -745,7 +791,7 @@ sub get_return_type_val
 
 sub get_arg_assert
 {
-	my ($rettype, $type_arg, $force) = @_;
+	my ($rettype, $type_arg, $force, $allow_null) = @_;
 	my ($type, $arg);
 	if ($type_arg =~ s/([\w_][\w\d_]*)+$//)
 	{
@@ -753,6 +799,10 @@ sub get_arg_assert
 		$type = $type_arg;
 		$type =~ s/\s//g;
 	}
+
+	## No asserts if type is not defined.
+	return "" if !defined ($type);
+	
 	if (!defined($force) || $force eq "")
 	{
 		$force = 0;
@@ -792,6 +842,10 @@ sub get_arg_assert
 			get_canonical_names($type, \$prefix, \$macro_prefix,
 								\$macro_suffix, \$macro_name);
 			$ainfo = $macro_prefix."_IS_".$macro_suffix."(__arg__)";
+			if ($allow_null)
+			{
+				$ainfo="(__arg__ == NULL) ||".$ainfo
+			}
 		}
 		else
 		{
@@ -801,7 +855,7 @@ sub get_arg_assert
 	}
 	if ($rettype eq "void")
 	{
-		$ainfo =~ s/__arg__/$arg/;
+		$ainfo =~ s/__arg__/$arg/g;
 		my $ret = "g_return_if_fail ($ainfo);";
 		return $ret;
 	}
@@ -810,7 +864,7 @@ sub get_arg_assert
 		my $fail_ret = get_return_type_val ($rettype);
 		if (defined($fail_ret))
 		{
-			$ainfo =~ s/__arg__/$arg/;
+			$ainfo =~ s/__arg__/$arg/g;
 			my $ret = "g_return_val_if_fail ($ainfo, $fail_ret);";
 			return $ret;
 		}
@@ -992,6 +1046,7 @@ sub generate_class
 	{
 		$answer .= "#include <$module_name/interfaces/$parent_include>\n";
 	}
+
 	$answer .=
 "
 G_BEGIN_DECLS
@@ -1022,12 +1077,36 @@ G_BEGIN_DECLS
 		$answer .= "\n";
 	}
 	
+	$answer .=
+"#define ${macro_name}_ERROR ${prefix}_error_quark()
+
+";
+
+	## Added defines;
+	my $defines_lr = $class_hr->{"__defines"};
+	if (defined ($defines_lr))
+	{
+		foreach my $d (@$defines_lr)
+		{
+			my $comments_out = $d->{'__comments'};
+			my $name = $d->{'name'};
+			my $value = $d->{'value'};
+			$answer .= "${comments_out}#define\t${macro_name}_${name}\t${value}\n\n";
+		}
+		$answer .= "\n";
+	}
+
+	$answer .=
+"typedef struct _$class $class;
+typedef struct _${class}Iface ${class}Iface;\n\n";
+
 	## Added enums;
 	if (defined ($enums_hr))
 	{
 		foreach my $e (sort keys %$enums_hr)
 		{
-			$answer .= "typedef enum {\n";
+			my $comments_out = $enums_hr->{$e}->{'__comments'};
+			$answer .= "${comments_out}typedef enum {\n";
 			foreach my $d (@{$enums_hr->{$e}->{"__data"}})
 			{
 				$answer .= "\t${macro_name}_$d\n";
@@ -1041,7 +1120,8 @@ G_BEGIN_DECLS
 	{
 		foreach my $s (sort keys %$structs_hr)
 		{
-			$answer .= "typedef struct _${class}$s ${class}$s;\n";
+			my $comments_out = $structs_hr->{$s}->{'__comments'};
+			$answer .= "${comments_out}typedef struct _${class}$s ${class}$s;\n";
 			$answer .= "struct _${class}$s {\n";
 			foreach my $d (@{$structs_hr->{$s}->{"__data"}})
 			{
@@ -1051,27 +1131,22 @@ G_BEGIN_DECLS
 			$answer .= "};\n\n";
 		}
 	}
-	
-	$answer .=
-"#define ${macro_name}_ERROR ${prefix}_error_quark()
 
-";
 	## Added Typedefs
 	my $typedefs_lr = $class_hr->{"__typedefs"};
 	if (defined ($typedefs_lr))
 	{
 		foreach my $td (@$typedefs_lr)
 		{
-			$td = normalize_namespace ($class, $td);
-			$answer .= $td . "\n";
+			my $comments_out = $td->{'__comments'};
+			my $line = normalize_namespace ($class, $td->{'line'});
+			$answer .= "${comments_out}${line}\n\n";
 		}
 		$answer .= "\n";
 	}
 	
 	$answer .=
-"typedef struct _$class $class;
-typedef struct _${class}Iface ${class}Iface;
-
+"
 struct _${class}Iface {
 	$parent_iface g_iface;
 	
@@ -1102,19 +1177,30 @@ struct _${class}Iface {
 		my $rettype = normalize_namespace($class, $class_hr->{$m}->{'rettype'});
 		my $args = normalize_namespace($class, $class_hr->{$m}->{'args'});
 		$args = convert_args($args);
-		if ($args ne '')
+
+		## No comma for the last arg if it's "..." variable args */
+		if ($args ne '' && $args !~ /\.\.\.$/)
 		{
 			$args .= ", ";
 		}
 		if ($func !~ /^\:\:/)
 		{
 			$rettype = convert_ret($rettype);
-			$answer .= "\t$rettype (*$func) ($class *obj, ${args}GError **err);\n";
+			## No GError **err arg for functions with variable args */
+			if ($args !~ /\.\.\.$/)
+			{
+				$answer .= "\t$rettype (*$func) ($class *obj, ${args}GError **err);\n";
+			}
+			else
+			{
+				$answer .= "\t$rettype (*$func) ($class *obj, ${args});\n";
+			}
 		}
 	}
 	$answer .=
 "
 };
+
 ";
 	# Enum GType prototypes.
 	if (defined ($enums_hr))
@@ -1145,14 +1231,21 @@ GType  ${prefix}_get_type        (void);
 		my $rettype = normalize_namespace($class, $class_hr->{$m}->{'rettype'});
 		my $args = normalize_namespace($class, $class_hr->{$m}->{'args'});
 		$args = convert_args($args);
-		if ($args ne '')
+		if ($args ne '' && $args !~ /\.\.\.$/)
 		{
 			$args .= ", ";
 		}
 		if ($func !~ /^\:\:/)
 		{
 			$rettype = convert_ret($rettype);
-			$answer .= "${rettype} ${prefix}_$func ($class *obj, ${args}GError **err);\n\n";
+			if ($args !~ /\.\.\.$/)
+			{
+				$answer .= "${rettype} ${prefix}_$func ($class *obj, ${args}GError **err);\n\n";
+			}
+			else
+			{
+				$answer .= "${rettype} ${prefix}_$func ($class *obj, ${args});\n\n";
+			}
 		}
 	}
 	$answer .=
@@ -1222,7 +1315,7 @@ ${prefix}_error_quark (void)
 		my $params = "";
 		next if ($func =~ /^\:\:/);
 
-		my $asserts = "\t".get_arg_assert($rettype, "$class *obj", 1)."\n";
+		my $asserts = "\t".get_arg_assert($rettype, "$class *obj", 1, 0)."\n";
 		## self assert;
 		$args = convert_args($args);
 		if ($args ne '')
@@ -1231,7 +1324,7 @@ ${prefix}_error_quark (void)
 			my @margs = split(",", $args);
 			foreach my $one_arg (@margs)
 			{
-				my $assert_stmt = get_arg_assert($rettype, $one_arg, 0);
+				my $assert_stmt = get_arg_assert($rettype, $one_arg, 0, 1);
 				if (defined($assert_stmt) && $assert_stmt ne "")
 				{
 					$asserts .= "\t$assert_stmt\n";
@@ -1296,6 +1389,7 @@ ${prefix}_base_init (${class}Iface* klass)
 	foreach my $m (sort keys %$class_hr)
 	{
 		next if ($m =~ /^__/);
+		my $comments_out = $class_hr->{$m}->{'__comments'};
 		my $func = $class_hr->{$m}->{'function'};
 		my $rettype = normalize_namespace($class, $class_hr->{$m}->{'rettype'});
 		my $args = normalize_namespace($class, $class_hr->{$m}->{'args'});
@@ -1310,8 +1404,9 @@ ${prefix}_base_init (${class}Iface* klass)
 			$signal =~ s/_/-/g;
 			
 			my $marshaller = construct_marshaller($rettype, $args);
-			$answer .= "\t\t/* Signal */";
-			$answer .="\n\t\tg_signal_new (\"$signal\",
+			$comments_out =~ s/\n/\n\t\t/g;
+			$answer .= "\n\t\t$comments_out";
+			$answer .="g_signal_new (\"$signal\",
 			$macro_type,
 			G_SIGNAL_RUN_LAST,
 			G_STRUCT_OFFSET (${class}Iface, $func),
