@@ -27,14 +27,15 @@
 #include <unistd.h>
 #include <string.h>
 #include <ctype.h>
-#include <gnome.h>
+#include <stdlib.h>
+#include <glib/gi18n.h>
+#include <gio/gio.h>
 
 /*#define DEBUG*/
 #include <libanjuta/resources.h>
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/interfaces/ianjuta-editor.h>
 #include <libanjuta/interfaces/ianjuta-document-manager.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
 
 #include "utilities.h"
 #include "info.h"
@@ -292,8 +293,10 @@ on_stack_trace_updated (const GList *stack, gpointer user_data, GError *error)
 		{
 			if (g_path_is_absolute (frame->file))
 			{					
-				uri = gnome_vfs_get_uri_from_local_path(frame->file);
-				file = strrchr(uri, '/') + 1;
+				GFile *gio_file = g_file_new_for_path (frame->file);
+				uri = g_file_get_uri (gio_file);
+				file = strrchr(frame->file, G_DIR_SEPARATOR) + 1;
+				g_object_unref (gio_file);
 			}
 			else
 			{
@@ -321,7 +324,7 @@ on_stack_trace_updated (const GList *stack, gpointer user_data, GError *error)
 		g_free (uri);
 		g_free (adr);
 	}
-	gdk_pixbuf_unref (pic);
+	g_object_unref (pic);
 	
 }
 
@@ -379,13 +382,13 @@ static gboolean
 on_find_stack_trace (gconstpointer a, gconstpointer b)
 {
 	const DmaThreadStackTrace *trace = (const DmaThreadStackTrace *)a;
-	guint thread = (gint)b;
+	guint thread = GPOINTER_TO_UINT(b);
 	
 	return trace->thread != thread;
 }
 
 static void
-dma_thread_set_stack_trace (StackTrace *self, gint thread)
+dma_thread_set_stack_trace (StackTrace *self, guint thread)
 {
 	GList *list;
 	DmaThreadStackTrace *trace;
@@ -394,7 +397,7 @@ dma_thread_set_stack_trace (StackTrace *self, gint thread)
 	{
 		self->current_frame = 0;
 		
-		list = g_list_find_custom (self->list, (gconstpointer) thread, on_find_stack_trace);
+		list = g_list_find_custom (self->list, GINT_TO_POINTER(thread), on_find_stack_trace);
 	
 		if (list == NULL)
 		{
@@ -453,7 +456,7 @@ on_frame_changed (StackTrace *self, guint frame, gint thread)
 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
 							STACK_TRACE_ACTIVE_COLUMN, pointer_pix,
 							-1);
-		gdk_pixbuf_unref (pointer_pix);
+		g_object_unref (pointer_pix);
 	}
 }
 
@@ -511,6 +514,31 @@ on_stack_view_source_activate (GtkAction *action, gpointer user_data)
 	g_free (adr);
 }
 
+static void
+on_got_stack_trace (const gchar *trace, gpointer user_data, GError *error)
+{
+	StackTrace* st = (StackTrace*) user_data;
+	IAnjutaDocumentManager *docman;
+
+	docman = anjuta_shell_get_interface (ANJUTA_PLUGIN (st->plugin)->shell, IAnjutaDocumentManager, NULL);
+	if (docman != NULL)
+	{
+		ianjuta_document_manager_add_buffer (docman, "Stack Trace", trace, NULL);
+	}
+}
+
+static void
+on_stack_get_trace (GtkAction *action, gpointer user_data)
+{
+	StackTrace* st = (StackTrace*) user_data;		
+
+	/* Ask debugger to get all frame data */
+	dma_queue_dump_stack_trace (
+			st->debugger,
+			(IAnjutaDebuggerCallback)on_got_stack_trace,
+			st);
+}
+
 static void
 on_stack_trace_row_activated           (GtkTreeView     *treeview,
                                         GtkTreePath     *arg1,
@@ -560,6 +588,14 @@ static GtkActionEntry actions_stack_trace[] = {
 		NULL,
 		NULL,
 		G_CALLBACK (on_stack_view_source_activate)
+	},
+	{
+		"ActionDmaDumpStackTrace",
+		NULL,
+		N_("Get Stack trace"),
+		NULL,
+		NULL,
+		G_CALLBACK (on_stack_get_trace)
 	}
 };		
 
