@@ -20,6 +20,8 @@
 
 #include <config.h>
 
+#include <stdlib.h>
+#include <unistd.h>
 #include <glib/gi18n.h>
 
 #include <libanjuta/anjuta-shell.h>
@@ -111,7 +113,7 @@ launch_application_failure (AnjutaFileLoaderPlugin *plugin,
 		gtk_widget_get_toplevel (GTK_WIDGET(ANJUTA_PLUGIN (plugin)->shell));
 	basename = g_path_get_basename (uri);
 	anjuta_util_dialog_error (GTK_WINDOW (parent),
-							  _("Can not open \"%s\".\n\n%s"),
+							  _("Cannot open \"%s\".\n\n%s"),
 							  basename, errmsg);
 	g_free (basename);
 }
@@ -190,19 +192,63 @@ get_available_plugins_for_mime (AnjutaPlugin* plugin,
 	return plugin_descs;
 }
 
+static gboolean
+RowSeparatorFunc (GtkTreeModel *model, GtkTreeIter *iter, gpointer data)
+{
+	int n = GPOINTER_TO_INT(data), k;
+	gchar *path = gtk_tree_model_get_string_from_iter (model, iter);
+	sscanf (path, "%d", &k);
+	g_free (path);
+	return n == k;
+}
+
+static void
+on_value_added_current_doc (AnjutaPlugin *plugin, const gchar *name,
+                            const GValue *value, gpointer data)
+{
+	AnjutaFileLoaderPlugin *fplugin = ANJUTA_PLUGIN_FILE_LOADER (plugin);
+	IAnjutaDocument* doc = IANJUTA_DOCUMENT(g_value_get_object (value));
+	GFile *file;
+
+	g_free (fplugin->dm_current_uri);
+
+	if (IANJUTA_IS_FILE (doc) &&
+	    ((file = ianjuta_file_get_file(IANJUTA_FILE (doc), NULL)) != NULL))
+	{
+		GFile* parent = g_file_get_parent (file);
+		fplugin->dm_current_uri = g_file_get_uri (parent);
+		g_object_unref (parent);
+		g_object_unref (file);
+	}
+	else
+	{
+
+		fplugin->dm_current_uri = NULL;
+	}	
+}
+
+static void
+on_value_removed_current_doc (AnjutaPlugin *plugin, const gchar *name,
+                              gpointer data)
+{
+	AnjutaFileLoaderPlugin *fplugin = ANJUTA_PLUGIN_FILE_LOADER (plugin);
+	g_free (fplugin->dm_current_uri);
+	fplugin->dm_current_uri = NULL;
+}
+
 static void
 open_with_dialog (AnjutaFileLoaderPlugin *plugin, const gchar *uri,
 				  const gchar *mime_type)
 {
 	GList *plugin_descs, *snode;
 	GList *mime_apps, *node;
-	GtkWidget *menu, *menuitem;
 	GAppInfo *mime_app;
 	
 	GtkWidget *dialog, *parent, *hbox, *label;
 	GtkWidget *options;
 	gchar *message;
 	gchar *basename;
+	gint col = -1;
 	AnjutaPluginManager *plugin_manager;
 	
 	plugin_manager = anjuta_shell_get_plugin_manager (ANJUTA_PLUGIN (plugin)->shell,
@@ -212,7 +258,7 @@ open_with_dialog (AnjutaFileLoaderPlugin *plugin, const gchar *uri,
 								 "There is no plugin, default action, or application "
 								 "configured to handle this file type.\n"
 								 "\n"
-								 "Mime type: %s\n"
+								 "MIME type: %s\n"
 								 "\n"
 								 "You may choose to try opening it with the following "
 								 "plugins or applications."),
@@ -222,24 +268,23 @@ open_with_dialog (AnjutaFileLoaderPlugin *plugin, const gchar *uri,
 	parent =
 		gtk_widget_get_toplevel (GTK_WIDGET(ANJUTA_PLUGIN (plugin)->shell));
 	dialog = gtk_message_dialog_new_with_markup (GTK_WINDOW (parent),
-									 GTK_DIALOG_DESTROY_WITH_PARENT,
-									 GTK_MESSAGE_INFO,
-									 GTK_BUTTONS_OK_CANCEL, message);
+	                                             GTK_DIALOG_DESTROY_WITH_PARENT,
+	                                             GTK_MESSAGE_INFO,
+	                                             GTK_BUTTONS_OK_CANCEL, "%s",
+	                                             message);
 	g_free (message);
 	
 	hbox = gtk_hbox_new (FALSE, 5);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG(dialog)->vbox), hbox,
-						FALSE, FALSE, 5);
+	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
+			    hbox, FALSE, FALSE, 5);
 	label = gtk_label_new (_("Open with:"));
-	options = gtk_option_menu_new ();
+	options = gtk_combo_box_new_text ();
 	gtk_box_pack_end (GTK_BOX(hbox), options, FALSE, FALSE, 10);
 	gtk_box_pack_end (GTK_BOX(hbox), label, FALSE, FALSE, 10);
 	
-	menu = gtk_menu_new ();
-	
 	/* Document manager plugin */
-	menuitem = gtk_menu_item_new_with_label (_("Document Manager"));
-	gtk_menu_append (menu, menuitem);
+	gtk_combo_box_append_text (GTK_COMBO_BOX (options), _("Document Manager"));
+	col ++;
 	
 	/* Open with plugins menu items */
 	plugin_descs = get_available_plugins_for_mime (ANJUTA_PLUGIN (plugin), mime_type);
@@ -266,8 +311,8 @@ open_with_dialog (AnjutaFileLoaderPlugin *plugin, const gchar *uri,
 			anjuta_plugin_description_get_string (desc, "Anjuta Plugin",
 												  "Location", &name);
 		}
-		menuitem = gtk_menu_item_new_with_label (name);
-		gtk_menu_append (menu, menuitem);
+		gtk_combo_box_append_text (GTK_COMBO_BOX (options), name);
+		col ++;
 		g_free (name);
 		snode = g_list_next (snode);
 	}
@@ -277,8 +322,9 @@ open_with_dialog (AnjutaFileLoaderPlugin *plugin, const gchar *uri,
 	if (mime_apps)
 	{
 		/* Separator */
-		menuitem = gtk_menu_item_new ();
-		gtk_menu_append (menu, menuitem);
+		col++;
+		gtk_combo_box_append_text (GTK_COMBO_BOX (options), "");
+		gtk_combo_box_set_row_separator_func (GTK_COMBO_BOX (options), RowSeparatorFunc, GINT_TO_POINTER(col), NULL);
 	}	
 	node = mime_apps;
 	while (node)
@@ -286,21 +332,18 @@ open_with_dialog (AnjutaFileLoaderPlugin *plugin, const gchar *uri,
 		mime_app = (GAppInfo *)(node->data);
 		if (g_app_info_should_show (mime_app))
 		{
-			menuitem = gtk_menu_item_new_with_label (
-					g_app_info_get_name (mime_app));
-			gtk_menu_append (menu, menuitem);
+			gtk_combo_box_append_text (GTK_COMBO_BOX (options), g_app_info_get_name (mime_app));
 		}
 		node = g_list_next (node);
 	}
-	
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (options), menu);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (options), 0);
 	gtk_widget_show_all (hbox);
 	
 	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
 	{
 		gint option;
 		
-		option = gtk_option_menu_get_history(GTK_OPTION_MENU (options));
+		option = gtk_combo_box_get_active(GTK_COMBO_BOX (options));
 		if (option == 0)
 		{
 			IAnjutaDocumentManager *docman;
@@ -379,16 +422,9 @@ open_with_dialog (AnjutaFileLoaderPlugin *plugin, const gchar *uri,
 static void
 open_file (AnjutaFileLoaderPlugin *plugin, const gchar *uri)
 {
-	gchar *dirname;
-	gchar *path;
 	GFile* file;
 	
 	file = g_file_new_for_uri (uri);
-	path = g_file_get_path (file);
-	dirname = g_path_get_dirname (uri);
-	chdir (dirname);
-	g_free (path);
-	g_free (dirname);
 	
 	ianjuta_file_loader_load (IANJUTA_FILE_LOADER (plugin),
 							  file, FALSE, NULL);
@@ -516,7 +552,7 @@ setup_file_filters (GtkFileChooser *fc)
 	gtk_file_chooser_add_filter (fc, filter);
 
 	filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (filter, _("Hyper text markup files"));
+	gtk_file_filter_set_name (filter, _("Hypertext markup files"));
 	gtk_file_filter_add_pattern (filter, "*.htm");
 	gtk_file_filter_add_pattern (filter, "*.html");
 	gtk_file_filter_add_pattern (filter, "*.xhtml");
@@ -525,7 +561,7 @@ setup_file_filters (GtkFileChooser *fc)
 	gtk_file_chooser_add_filter (fc, filter);
 
 	filter = gtk_file_filter_new ();
-	gtk_file_filter_set_name (filter, _("Shell scripts files"));
+	gtk_file_filter_set_name (filter, _("Shell script files"));
 	gtk_file_filter_add_pattern (filter, "*.sh");
 	gtk_file_chooser_add_filter (fc, filter);
 
@@ -559,6 +595,11 @@ create_file_open_dialog_gui(GtkWindow* parent, AnjutaFileLoaderPlugin* plugin)
 									GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 									NULL);
 	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER(dialog), TRUE);
+	if (plugin->dm_current_uri)
+	{
+		gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (dialog),
+		                                         plugin->dm_current_uri);
+	}
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (dialog), FALSE);
 	gtk_dialog_set_default_response (GTK_DIALOG(dialog), GTK_RESPONSE_ACCEPT);
 	gtk_window_set_destroy_with_parent (GTK_WINDOW(dialog), TRUE);
@@ -848,7 +889,7 @@ static GtkActionEntry actions_file[] = {
 	{
 		"ActionFileOpen",
 		GTK_STOCK_OPEN,
-		N_("_Open..."),
+		N_("_Open…"),
 		"<control>o",
 		N_("Open file"),
 		G_CALLBACK (on_open_activate)
@@ -934,7 +975,7 @@ create_open_with_submenu (AnjutaFileLoaderPlugin *plugin, GtkWidget *parentmenu,
 		g_object_set_data (G_OBJECT (menuitem), "mime_type", mime_type);			
 		g_signal_connect (G_OBJECT (menuitem), "activate",
 						  G_CALLBACK (callback), callback_data);
-		gtk_menu_append (menu, menuitem);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 		g_free (name);
 	}
 	g_list_free (plugin_descs);
@@ -944,7 +985,7 @@ create_open_with_submenu (AnjutaFileLoaderPlugin *plugin, GtkWidget *parentmenu,
 	if (plugin_descs && mime_apps)
 	{
 		menuitem = gtk_menu_item_new ();
-		gtk_menu_append (menu, menuitem);
+		gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 	}
 	
 	for (node = mime_apps; node != NULL; node = g_list_next (node))
@@ -959,7 +1000,7 @@ create_open_with_submenu (AnjutaFileLoaderPlugin *plugin, GtkWidget *parentmenu,
 			g_object_set_data (G_OBJECT (menuitem), "mime_type", mime_type);			
 			g_signal_connect (G_OBJECT (menuitem), "activate",
 							  G_CALLBACK (callback), callback_data);
-			gtk_menu_append (menu, menuitem);
+			gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 		}
 		else
 		{
@@ -1104,11 +1145,9 @@ value_removed_pm_current_uri (AnjutaPlugin *plugin,
 }
 
 static void
-dnd_dropped (const gchar *uri, gpointer plugin)
+dnd_dropped (GFile* file, gpointer plugin)
 {
-	GFile* file = g_file_new_for_uri (uri);
 	ianjuta_file_loader_load (IANJUTA_FILE_LOADER (plugin), file, FALSE, NULL);
-	g_object_unref (file);
 }
 
 static void
@@ -1191,7 +1230,7 @@ activate_plugin (AnjutaPlugin *plugin)
 	
 	loader_plugin = ANJUTA_PLUGIN_FILE_LOADER (plugin);
 	
-	DEBUG_PRINT ("%s", "AnjutaFileLoaderPlugin: Activating File Loader plugin...");
+	DEBUG_PRINT ("%s", "AnjutaFileLoaderPlugin: Activating File Loader plugin…");
 	
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
 	
@@ -1265,9 +1304,7 @@ activate_plugin (AnjutaPlugin *plugin)
 	g_signal_connect (widget, "clicked", G_CALLBACK (on_open_clicked), loader_plugin);
 
 	/* Install drag n drop handler */
-	dnd_drop_init (GTK_WIDGET (plugin->shell), dnd_dropped, plugin,
-				   "text/plain", "text/html", "text/source", "application-x/anjuta",
-				   NULL);
+	dnd_drop_init (GTK_WIDGET (plugin->shell), dnd_dropped, plugin);
 	
 	/* Add watches */
 	loader_plugin->fm_watch_id = 
@@ -1278,6 +1315,12 @@ activate_plugin (AnjutaPlugin *plugin)
 		anjuta_plugin_add_watch (plugin, IANJUTA_PROJECT_MANAGER_CURRENT_URI,
 								 value_added_pm_current_uri,
 								 value_removed_pm_current_uri, NULL);
+	loader_plugin->dm_watch_id = 
+		anjuta_plugin_add_watch (plugin,
+								  IANJUTA_DOCUMENT_MANAGER_CURRENT_DOCUMENT,
+								 on_value_added_current_doc,
+								 on_value_removed_current_doc,
+								 plugin);
 	
 	/* Connect to session */
 	g_signal_connect (G_OBJECT (plugin->shell), "load_session",
@@ -1293,7 +1336,7 @@ deactivate_plugin (AnjutaPlugin *plugin)
 	
 	loader_plugin = ANJUTA_PLUGIN_FILE_LOADER (plugin);
 	
-	DEBUG_PRINT ("%s", "AnjutaFileLoaderPlugin: Deactivating File Loader plugin...");
+	DEBUG_PRINT ("%s", "AnjutaFileLoaderPlugin: Deactivating File Loader plugin…");
 	
 	/* Disconnect session */
 	g_signal_handlers_disconnect_by_func (G_OBJECT (plugin->shell),
@@ -1334,6 +1377,7 @@ anjuta_file_loader_plugin_instance_init (GObject *obj)
 	
 	plugin->fm_current_uri = NULL;
 	plugin->pm_current_uri = NULL;
+	plugin->dm_current_uri = NULL;	
 }
 
 static void
