@@ -29,10 +29,13 @@
 #include <libanjuta/anjuta-preferences.h>
 
 #include "file-view.h"
+#include "file-model.h"
 
 typedef struct _AnjutaFileManager AnjutaFileManager;
 typedef struct _AnjutaFileManagerClass AnjutaFileManagerClass;
 
+extern GType file_manager_get_type (GTypeModule *module);
+
 struct _AnjutaFileManager {
 	AnjutaPlugin parent;
 	AnjutaFileView* fv;
@@ -42,8 +45,7 @@ struct _AnjutaFileManager {
 	
 	gint uiid;
 	GtkActionGroup *action_group;
-	GList* gconf_notify_ids;
-	AnjutaPreferences* prefs;
+	GList* notify_ids;
 };
 
 struct _AnjutaFileManagerClass {
