@@ -12,13 +12,13 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #ifndef _ANJUTA_MSGMAN_H
 #define _ANJUTA_MSGMAN_H
 
-#include <gtk/gtknotebook.h>
+#include <gtk/gtk.h>
 #include <libanjuta/anjuta-preferences.h>
 #include "message-view.h"
 
@@ -38,6 +38,9 @@ struct _AnjutaMsgman
 {
 	GtkNotebook parent;
 	AnjutaMsgmanPriv *priv;
+	
+	/* Signal */
+	void (*view_changed) (AnjutaMsgman *obj);
 };
 
 struct _AnjutaMsgmanClass
@@ -46,7 +49,7 @@ struct _AnjutaMsgmanClass
 };
 
 GType anjuta_msgman_get_type (void);
-GtkWidget *anjuta_msgman_new (AnjutaPreferences * pref, GtkWidget* popup_menu);
+GtkWidget *anjuta_msgman_new (GtkWidget* popup_menu);
 
 MessageView *anjuta_msgman_add_view (AnjutaMsgman * msgman,
 									 const gchar * name,
@@ -65,13 +68,21 @@ GList *anjuta_msgman_get_all_views (AnjutaMsgman * msgman);
 void anjuta_msgman_set_view_title (AnjutaMsgman *msgman, MessageView *view,
 								   const gchar *title);
 
+void anjuta_msgman_set_view_icon (AnjutaMsgman *msgman, MessageView *view,
+								  GdkPixbufAnimation *icon);
+
+void anjuta_msgman_set_view_icon_from_stock (AnjutaMsgman *msgman, MessageView *view,
+								             const gchar *icon);
+
 gboolean anjuta_msgman_serialize (AnjutaMsgman *msgman,
 								  AnjutaSerializer *serializer);
 gboolean anjuta_msgman_deserialize (AnjutaMsgman *msgman,
 									AnjutaSerializer *serializer);
 
+GtkWidget* anjuta_msgman_get_tabber (AnjutaMsgman* msgman);
+
 void
-on_gconf_notify_message_pref (GConfClient *gclient, guint cnxn_id,
-					   GConfEntry *entry, gpointer user_data);
+on_notify_message_pref (AnjutaPreferences* prefs, const gchar* key,
+                        const gchar* value, gpointer user_data);
 
 #endif /* _ANJUTA_MSGMAN_H */
