@@ -299,8 +299,8 @@ on_select_target (RunDialog* dlg)
 	GtkWidget *sel_dlg = gtk_file_chooser_dialog_new (
 			_("Load Target to run"), GTK_WINDOW (dlg->win),
 			 GTK_FILE_CHOOSER_ACTION_OPEN,
-			 GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-			 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
+			 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			 GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT, NULL);
 	gtk_file_chooser_set_select_multiple (GTK_FILE_CHOOSER(sel_dlg), FALSE);
 	gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (sel_dlg), TRUE);
 
@@ -678,7 +678,7 @@ run_dialog_init (RunDialog *dlg, RunProgramPlugin *plugin)
 		if (pm != NULL)
 		{
 			exec_targets = ianjuta_project_manager_get_targets (pm,
-							 IANJUTA_PROJECT_MANAGER_TARGET_EXECUTABLE,
+							 ANJUTA_TARGET_EXECUTABLE,
 							 NULL);
 		}
 		if (exec_targets != NULL)
@@ -688,15 +688,17 @@ run_dialog_init (RunDialog *dlg, RunProgramPlugin *plugin)
 			for (node = exec_targets; node; node = g_list_next (node))
 			{
 				GList *target;
+				gchar *uri = g_file_get_uri ((GFile *)node->data);
 				for (target = plugin->recent_target; target; target = g_list_next (target))
 				{
-					if (strcmp ((const gchar *)target->data, node->data) == 0) break;
+					if (strcmp ((const gchar *)target->data, uri) == 0) break;
 				}
 				if (target == NULL)
 				{
-					on_add_uri_in_model (node->data, model);
+					on_add_uri_in_model (uri, model);
 				}
-				g_free (node->data);
+				g_free (uri);
+				g_object_unref (node->data);
 			}
 			g_list_free (exec_targets);
 		}
