@@ -219,7 +219,7 @@ anjuta_view_drag_data_received (GtkWidget        *widget,
 	/* If this is an URL emit DROP_URIS, otherwise chain up the signal */
 	if (info == TARGET_URI_LIST)
 	{
-		files = anjuta_utils_drop_get_files (selection_data);
+		files = anjuta_util_drop_get_files (selection_data);
 
 		if (files != NULL)
 		{
@@ -676,8 +676,6 @@ anjuta_view_key_press_event		(GtkWidget *widget, GdkEventKey       *event)
 	buffer  = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
 	
 	assist_tip = view->priv->sv->priv->assist_tip;
-	if (assist_tip)
-	{
     switch (event->keyval)
     {
       case GDK_Escape:
@@ -685,9 +683,21 @@ anjuta_view_key_press_event		(GtkWidget *widget, GdkEventKey       *event)
       case GDK_Down:
       case GDK_Page_Up:
       case GDK_Page_Down:
-        gtk_widget_destroy (GTK_WIDGET(assist_tip));
-        break;
-		}
+				if (assist_tip)
+				{
+					gtk_widget_destroy (GTK_WIDGET(assist_tip));
+					break;
+				}
+				break;
+			case GDK_F7:
+				/* F7 is used to toggle cursor visibility but we rather like to
+				 * use it as shortcut for building (#611204)
+				 */
+				return FALSE;
+			case GDK_Return:
+				/* Ctrl-Return is used for autocompletion */
+				if (event->state == GDK_CONTROL_MASK)
+					return FALSE;
 	}
 	return (* GTK_WIDGET_CLASS (anjuta_view_parent_class)->key_press_event)(widget, event);
 }
