@@ -81,7 +81,6 @@ static void
 sourceview_io_class_init (SourceviewIOClass *klass)
 {
 	GObjectClass* object_class = G_OBJECT_CLASS (klass);
-	GObjectClass* parent_class = G_OBJECT_CLASS (klass);
 
 	object_class->finalize = sourceview_io_finalize;
 
@@ -241,7 +240,7 @@ on_save_finished (GObject* file, GAsyncResult* result, gpointer data)
 	SourceviewIO* sio = SOURCEVIEW_IO(data);
 	AnjutaShell* shell = ANJUTA_PLUGIN (sio->sv->priv->plugin)->shell;
 	GError* err = NULL;
-	gchar* etag;
+	gchar* etag = NULL;
 	g_file_replace_contents_finish (G_FILE (file),
 	                                result,
 	                                &etag,
